# History of changes

## Version 0.6.1 (2020-01-08)

### Pull Requests Merged

* [PR 130](https://github.com/spyder-ide/qtawesome/pull/130) - PR: Improve sponsors section in readme
* [PR 128](https://github.com/spyder-ide/qtawesome/pull/128) - PR: Replace QtGui by QtWidgets in docs
* [PR 126](https://github.com/spyder-ide/qtawesome/pull/126) - PR: Update MDI to 4.5.95
* [PR 122](https://github.com/spyder-ide/qtawesome/pull/122) - PR: Update MDI to 4.4.95
* [PR 121](https://github.com/spyder-ide/qtawesome/pull/121) - PR: Update number of icons in Readme and docs

In this release 5 pull requests were closed.


----


## Version 0.6.0 (2019-07-25)

### New features

* Add rotated, hflip, and vflip options

### Issues Closed

* [Issue 119](https://github.com/spyder-ide/qtawesome/issues/119) - Update FontAwesome and Material design icons ([PR 120](https://github.com/spyder-ide/qtawesome/pull/120))
* [Issue 112](https://github.com/spyder-ide/qtawesome/issues/112) - Rotate icons by static angle i.e. 90, 180 etc ([PR 117](https://github.com/spyder-ide/qtawesome/pull/117))

In this release 2 issues were closed.

### Pull Requests Merged

* [PR 120](https://github.com/spyder-ide/qtawesome/pull/120) - PR: Update FontAwesome and Material design icons ([119](https://github.com/spyder-ide/qtawesome/issues/119))
* [PR 117](https://github.com/spyder-ide/qtawesome/pull/117) - PR: Add rotated, hflip, and vflip options ([112](https://github.com/spyder-ide/qtawesome/issues/112))

In this release 2 pull requests were closed.


----


## Version 0.5.8 (2019-07-23)

### Pull Requests Merged

* [PR 118](https://github.com/spyder-ide/qtawesome/pull/118) - PR: Remove Python 3.8 deprecation warnings

In this release 1 pull request was closed.


----


## Version 0.5.7 (2019-03-07)

### Issues Closed

* [Issue 113](https://github.com/spyder-ide/qtawesome/issues/113) - Corrupted icons with PyQt 5.12 ([PR 115](https://github.com/spyder-ide/qtawesome/pull/115))

In this release 1 issue was closed.

### Pull Requests Merged

* [PR 115](https://github.com/spyder-ide/qtawesome/pull/115) - PR: Keep icons alive in cache ([113](https://github.com/spyder-ide/qtawesome/issues/113))

In this release 1 pull request was closed.


----


## Version 0.5.6 (2019-01-26)

### Issues Closed

* [Issue 107](https://github.com/spyder-ide/qtawesome/issues/107) - Some FontAwesome icons do not match ([PR 109](https://github.com/spyder-ide/qtawesome/pull/109))

In this release 1 issue was closed.

### Pull Requests Merged

* [PR 110](https://github.com/spyder-ide/qtawesome/pull/110) - PR: Update update_fa5 command to rename internal font names during update
* [PR 109](https://github.com/spyder-ide/qtawesome/pull/109) - PR: Rename FA5 fonts to be unique ([107](https://github.com/spyder-ide/qtawesome/issues/107))
* [PR 108](https://github.com/spyder-ide/qtawesome/pull/108) - PR: Add a test to ensure all fonts used by QtAwesome have a unique family name

In this release 3 pull requests were closed.


----


## Version 0.5.5 (2019-01-03)

### Pull Requests Merged

* [PR 106](https://github.com/spyder-ide/qtawesome/pull/106) - PR: Add setupbase.py to our tarball

In this release 1 pull request was closed.


----


## Version 0.5.4 (2019-01-03)

### Pull Requests Merged

* [PR 105](https://github.com/spyder-ide/qtawesome/pull/105) - PR: Fix bad package dependency in docs/environment.yml
* [PR 104](https://github.com/spyder-ide/qtawesome/pull/104) - PR: Update to FA 5.6.3 and new "update_fa5" setup.py subcommand

In this release 2 pull requests were closed.


----


## Version 0.5.3 (2018-11-12)

### Issues Closed

* [Issue 103](https://github.com/spyder-ide/qtawesome/issues/103) - Pypi description is ugly

In this release 1 issue was closed.

### Pull Requests Merged

* [PR 102](https://github.com/spyder-ide/qtawesome/pull/102) - PR: Update FontAwesome to 5.4.2

In this release 1 pull request was closed.


----


## Version 0.5.2 (2018-10-28)

### Pull Requests Merged

* [PR 101](https://github.com/spyder-ide/qtawesome/pull/101) - PR: Generate PyPI long description from README.md
* [PR 100](https://github.com/spyder-ide/qtawesome/pull/100) - PR: Add instruction to update MDI
* [PR 99](https://github.com/spyder-ide/qtawesome/pull/99) - PR: Update MDI to 3.0.39

In this release 3 pull requests were closed.


----


## Version 0.5.1 (2018-09-30)

### Issues Closed

* [Issue 97](https://github.com/spyder-ide/qtawesome/issues/97) - minus-circle not working ([PR 98](https://github.com/spyder-ide/qtawesome/pull/98))

In this release 1 issue was closed.

### Pull Requests Merged

* [PR 98](https://github.com/spyder-ide/qtawesome/pull/98) - PR: Rename FontAwesome5 fonts ([97](https://github.com/spyder-ide/qtawesome/issues/97))

In this release 1 pull request was closed.


----


## Version 0.5 (2018-09-18)

### New features

* Update FontAwesome 4 to 4.7. Its namespace will be `fa` forever.
* Add Material Design icons under the `mdi` namespace
* Add FontAwesome 5 icons under the `fa5` (regular), `fa5s` (solid) and
  `fa5b` (brands) namespaces.

### Issues Closed

* [Issue 93](https://github.com/spyder-ide/qtawesome/issues/93) - Update MDI to 2.7.94 ([PR 95](https://github.com/spyder-ide/qtawesome/pull/95))
* [Issue 88](https://github.com/spyder-ide/qtawesome/issues/88) - Add support for Material Design Icons ([PR 92](https://github.com/spyder-ide/qtawesome/pull/92))
* [Issue 87](https://github.com/spyder-ide/qtawesome/issues/87) - Update FontAwesome to its 5 version ([PR 86](https://github.com/spyder-ide/qtawesome/pull/86))
* [Issue 76](https://github.com/spyder-ide/qtawesome/issues/76) - Error in animation.py when quickly set spinner ([PR 77](https://github.com/spyder-ide/qtawesome/pull/77))
* [Issue 41](https://github.com/spyder-ide/qtawesome/issues/41) - Add .project and .pydevproject to .gitignore ([PR 96](https://github.com/spyder-ide/qtawesome/pull/96))

In this release 5 issues were closed.

### Pull Requests Merged

* [PR 96](https://github.com/spyder-ide/qtawesome/pull/96) - PR: Ignore PyDev project files ([41](https://github.com/spyder-ide/qtawesome/issues/41))
* [PR 95](https://github.com/spyder-ide/qtawesome/pull/95) - PR: Update MDI to 2.7.94 ([93](https://github.com/spyder-ide/qtawesome/issues/93))
* [PR 92](https://github.com/spyder-ide/qtawesome/pull/92) - PR: Add Material Design Icons support ([88](https://github.com/spyder-ide/qtawesome/issues/88))
* [PR 91](https://github.com/spyder-ide/qtawesome/pull/91) - PR: Fix testing facilities
* [PR 86](https://github.com/spyder-ide/qtawesome/pull/86) - PR: Update FontAwesome to 5.3.1 ([87](https://github.com/spyder-ide/qtawesome/issues/87))
* [PR 85](https://github.com/spyder-ide/qtawesome/pull/85) - PR: Update readme to remove funding appeal, harmonize with other readmes and minor fixes
* [PR 81](https://github.com/spyder-ide/qtawesome/pull/81) - PR: Replace qRound (missing in PySide2) with round
* [PR 77](https://github.com/spyder-ide/qtawesome/pull/77) - PR: Fix error when updating animations ([76](https://github.com/spyder-ide/qtawesome/issues/76))
* [PR 72](https://github.com/spyder-ide/qtawesome/pull/72) - PR: Updating FontAwesome to 4.7

In this release 9 pull requests were closed.


----


## Version 0.4.4 (2017-01-28)

### Bugs fixed

**Pull requests**

* [PR 70](https://github.com/spyder-ide/qtawesome/pull/70) - PR: Prevent segfaults when importing QtAwesome out of a of QApplication

In this release 1 pull request was merged


----


## Version 0.4.3 (2017-01-22)

### Bugs fixed

**Pull requests**

* [PR 68](https://github.com/spyder-ide/qtawesome/pull/68) - PR: Include example script into tarball to run tests when the package is installed

In this release 1 pull request was merged


----


## Version 0.4.2 (2017-01-21)

### Bugs fixed

**Issues**

* [Issue 65](https://github.com/spyder-ide/qtawesome/issues/65) - Update Appveyor Badge for new username spyder-ide
* [Issue 64](https://github.com/spyder-ide/qtawesome/issues/64) - Integration with system fonts
* [Issue 51](https://github.com/spyder-ide/qtawesome/issues/51) - Include  doc files in PyPi releases

In this release 3 issues were closed

**Pull requests**

* [PR 67](https://github.com/spyder-ide/qtawesome/pull/67) - PR: Add a way to not verify hash of vendorized fonts
* [PR 66](https://github.com/spyder-ide/qtawesome/pull/66) - PR: Update AppVeyor badge because of move to org account
* [PR 63](https://github.com/spyder-ide/qtawesome/pull/63) - Update manifest template

In this release 3 pull requests were merged


----


## Version 0.4.1 (2017-01-02)

### Bugs fixed

**Pull requests**

* [PR 62](https://github.com/spyder-ide/qtawesome/pull/62) - Improve verification that our fonts are not empty and/or missing

In this release 1 pull request was merged


----


## Version 0.4 (2017/01/01)

### New features

* Add a FontError exception to be able to catch an error on Windows 10, which
  prevents reading fonts not installed in the system.

### Bugs fixed

**Issues**

* [Issue 55](https://github.com/spyder-ide/qtawesome/issues/55) - Add appveyor integration
* [Issue 54](https://github.com/spyder-ide/qtawesome/issues/54) - Add travis ci integration for mac
* [Issue 53](https://github.com/spyder-ide/qtawesome/issues/53) - Add circle ci integration for linux

In this release 3 issues were closed

**Pull requests**

* [PR 61](https://github.com/spyder-ide/qtawesome/pull/61) - PR: Fix errors in CI services
* [PR 60](https://github.com/spyder-ide/qtawesome/pull/60) - PR: Add validation to raise exception when fonts are empty or corrupt
* [PR 57](https://github.com/spyder-ide/qtawesome/pull/57) - PR: Simplify appveyor and circle ci config
* [PR 56](https://github.com/spyder-ide/qtawesome/pull/56) - PR: Add ciocheck and circle ci linux integration
* [PR 50](https://github.com/spyder-ide/qtawesome/pull/50) - PR: Conda installation instructions
* [PR 49](https://github.com/spyder-ide/qtawesome/pull/49) - PR: Remove conda recipe
* [PR 48](https://github.com/spyder-ide/qtawesome/pull/48) - PR: Improve documentation

In this release 7 pull requests were merged
